@@ -31,7 +31,8 @@ class Config:
 		self.password = ""
 		self.color = ""
 		self.lastplayed = ""
-		self.config_opts = ['user','password']
+		self.format = "mp3"
+		self.config_opts = ['user','password','format']
 
 	def write(self):
 		if not os.path.exists(os.path.expanduser("~")+'/.config'):
@@ -39,7 +40,7 @@ class Config:
 
 		if not os.path.exists(os.path.expanduser("~")+'/.config/pyradio'):
 			os.mkdir(os.path.expanduser("~")+'/.config/pyradio')
-		newfile = "user="+self.user+"\npassword="+self.password+"\n"
+		newfile = "user="+self.user+"\npassword="+self.password+"\n"+"format="+self.format+"\n"
 		f = open(os.path.expanduser("~")+'/.config/pyradio/config', 'w')
 		f.write(newfile)
 		f.close()
@@ -89,6 +90,7 @@ class Panda(QtGui.QMainWindow):
 		self.c = Config()
 		self.c.load()
 		self.player = RadioPlayer()
+		self.player.format=self.c.format
 		self.player.start()
 		self.pui = Ui_pyRadio_portrait()
 		self.pui.setupUi(self)
@@ -177,6 +179,7 @@ class Panda(QtGui.QMainWindow):
 		QtCore.QObject.connect(self.player,QtCore.SIGNAL("authFail"), self.sigAuth)
 		QtCore.QObject.connect(self.player,QtCore.SIGNAL("stationCreated"), self.stationCreated)
 		QtCore.QObject.connect(self.player,QtCore.SIGNAL("duration"), self.setDuration)
+		QtCore.QObject.connect(self.player,QtCore.SIGNAL("state(QString)"), self.doPlayPause)
 		QtCore.QObject.connect(self.s, QtCore.SIGNAL('shutdown'), self.closeEvent)
 		QtCore.QObject.connect(self.ui.actionUser_Pass, QtCore.SIGNAL('triggered()'), self.setUserPass)
 		QtCore.QObject.connect(self.ui.actionDelete, QtCore.SIGNAL('triggered()'), self.deleteStation)
@@ -184,6 +187,7 @@ class Panda(QtGui.QMainWindow):
 		QtCore.QObject.connect(self.ui.actionSnooze, QtCore.SIGNAL('triggered()'), self.setSnooze)
 		QtCore.QObject.connect(self.ui.actionCreate, QtCore.SIGNAL('triggered()'), self.createStation)
 		QtCore.QObject.connect(self.ui.actionDonate, QtCore.SIGNAL('triggered()'), self.open_donate)
+		QtCore.QObject.connect(self.ui.actionQuality, QtCore.SIGNAL('triggered()'), self.open_quality)
 
 	def open_donate( self ):
 		self.d = QDialog(self)
@@ -197,17 +201,52 @@ class Panda(QtGui.QMainWindow):
 		hLayout = QHBoxLayout()
 		m = QPushButton("pyRadio")
 		p = QPushButton("Get Pandora One")
+		c = QPushButton("Close")
 		hLayout.addWidget(m)
 		hLayout.addWidget(p)
+		hLayout.addWidget(c)
 		action = lambda: self.donate('radio')
 		action1 = lambda: self.donate('pandora')
 		m.clicked.connect(action)
 		p.clicked.connect(action1)
+		c.clicked.connect(self.d.close)
 		vbox.addLayout(hLayout)
 		self.d.setLayout(vbox)
 		self.d.setWindowTitle("Donate to:")
 		self.d.show()
 
+	def open_quality( self ):
+		self.d = QDialog(self)
+		self.d.setParent(self)
+		if self.os == "RX-51":
+			if not self.portrait:
+				self.d.setAttribute(Qt.WA_Maemo5LandscapeOrientation, 1)
+			else:
+				self.d.setAttribute(Qt.WA_Maemo5PortraitOrientation, 1)
+		vbox = QVBoxLayout()
+		hLayout = QHBoxLayout()
+		m = QPushButton("AAC\n(low)")
+		p = QPushButton("MP3\n(Normal)")
+		c = QPushButton("MP3 High\n(Pandora One)")
+		hLayout.addWidget(m)
+		hLayout.addWidget(p)
+		hLayout.addWidget(c)
+		m.clicked.connect(lambda: self.setFormat("aacplus"))
+		p.clicked.connect(lambda: self.setFormat("mp3"))
+		c.clicked.connect(lambda: self.setFormat("mp3-hifi"))
+		vbox.addLayout(hLayout)
+		self.d.setLayout(vbox)
+		self.d.setWindowTitle("Sound Quality:")
+		self.d.show()
+
+	def setFormat(self, format="mp3"):
+		self.c.format=format
+		self.c.write()
+		self.player.format=format
+		self.player.playlist = []
+		self.player.getPlaylist = 1
+		self.d.close()
+
 	def donate( self, who=None ):
 		if who == 'radio':		
 			webbrowser.open_new('https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=BWX2M54JBJ2T2')
@@ -317,15 +356,17 @@ class Panda(QtGui.QMainWindow):
 	def nextUp(self):
 		self.ui.btnNext.setStyleSheet("background-color: rgb(0, 0, 0);\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/skip-trans.png);")
 
-	def doPlayPause( self ):
+	def doPlayPause( self, signal=None ):
 		if self.player.playing:
-			self.player.stopPlayBack('pause')
-			self.player.playing = 0
-			self.ui.btnPlay.setStyleSheet("background-color: "+ self.c.color +";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/paused-trans.png);")
+			if signal != "play":
+				self.player.stopPlayBack('pause')
+				self.player.playing = 0
+				self.ui.btnPlay.setStyleSheet("background-color: "+ self.c.color +";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/paused-trans.png);")
 		elif self.player.playlist != []:
-			self.player.startPlayBack()
-			self.player.playing = 1
-			self.ui.btnPlay.setStyleSheet("background-color: "+ self.c.color +";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/playing-trans.png);")
+			if signal != "pause":
+				self.player.startPlayBack()
+				self.player.playing = 1
+				self.ui.btnPlay.setStyleSheet("background-color: "+ self.c.color +";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/playing-trans.png);")
 		else:
 			self.playStation()
 			self.player.playing = 1
